Crate clawser_browser

Crate clawser_browser 

Antidetect browser automation powered by chromiumoxide CDP.

use clawser_browser::Browser;

#[tokio::main]
async fn main() -> clawser_browser::Result<()> {
    let browser = Browser::builder()
        .headful()
        .profile(7, 777)
        .build().await?;

    let page = browser.new_page("https://example.com").await?;
    let title = page.js("document.title").await?;
    println!("{title}");
    browser.close().await
}

Re-exports

pub use wreq;

Modules

header
HTTP header types

Structs

Browser
BrowserBuilder
HttpClient
HTTP client impersonating Chrome 134 at TLS + HTTP/2 level.
HttpClientBuilder
Builder for HttpClient.
HwProfile
Page

Statics

PROFILES

Functions

generate_config_json
Generate a complete clawser config JSON for the given profile and seed.
random_profile
Pick a random profile index and seed using OS time + counter.
write_config_file
Write config JSON to temp file, return the canonical Windows path.

Type Aliases

Result