Antidetect browser automation powered by chromiumoxide CDP.
use clawser_browser::Browser;
#[tokio::main]
async fn main() -> clawser_browser::Result<()> {
let browser = Browser::builder()
.headful()
.profile(7, 777)
.build().await?;
let page = browser.new_page("https://example.com").await?;
let title = page.js("document.title").await?;
println!("{title}");
browser.close().await
}Structs
Statics
Functions
- generate_
config_ json - Generate a complete clawser config JSON for the given profile and seed.
- random_
profile - Pick a random profile index and seed using OS time + counter.
- write_
config_ file - Write config JSON to temp file, return the canonical Windows path.