OrigHeaderMap

Struct OrigHeaderMap 

pub struct OrigHeaderMap(/* private fields */);
A map from header names to their original casing as received in an HTTP message.

OrigHeaderMap not only preserves the original case of each header name as it appeared in the request or response, but also maintains the insertion order of headers. This makes it suitable for use cases where the order of headers matters, such as HTTP/1.x message serialization, proxying, or reproducing requests/responses exactly as received.

Implementations

Source

impl OrigHeaderMap

pub fn new() -> OrigHeaderMap

Creates a new, empty OrigHeaderMap.

pub fn with_capacity(size: usize) -> OrigHeaderMap

Creates an empty OrigHeaderMap with the specified capacity.

pub fn insert<N>(&mut self, orig: N) -> bool

Insert a new header name into the collection.

If the map did not previously have this key present, then false is returned.

If the map did have this key present, the new value is pushed to the end of the list of values currently associated with the key. The key is not updated, though; this matters for types that can be == without being identical.

pub fn extend(&mut self, iter: OrigHeaderMap)

Extends the map with all entries from another OrigHeaderMap, preserving order.

pub fn len(&self) -> usize

Returns the number of headers stored in the map.

This number represents the total number of values stored in the map. This number can be greater than or equal to the number of keys stored given that a single key may have more than one associated value.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn iter(&self) -> impl Iterator<Item = (&HeaderName, &OrigHeaderName)>

Returns an iterator over all header names and their original spellings, in insertion order.